#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.3.0.0-3xiUP5jqlXq4Gg8E0oeuGq

key:
    hls-change-type-signature-plugin-2.3.0.0-3xiUP5jqlXq4Gg8E0oeuGq

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  43dee984f30cda240322039ad19d6b79
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.3.0.0-3xiUP5jqlXq4Gg8E0oeuGq

depends:
    base-4.18.2.1 containers-0.6.7 ghcide-2.3.0.0-9MX9KkPiOWIFpwMz4KO57
    hls-plugin-api-2.3.0.0-IQT22PBObv23WRuowMhdPw
    lsp-types-2.0.2.0-6kjARmZz5SuJJynM8KbziL
    regex-tdfa-1.3.2.5-6zmUIdhGbUZEJaVpWcqCOZ
    syb-0.7.3-GhxEKVO9aRZHddME5iK0hL text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

